All pastes #595095 Raw Edit

Stuff

public text v1 · immutable
#595095 ·published 2007-06-29 09:28 UTC
rendered paste body
dialog Remote.Creator {
  title "Noobie Remote Creator v1.2 - By Kurdish_Assass1n"
  size -1 -1 281 178
  option dbu
  combo 1, 9 12 80 76, size drop
  box "Create A Remote", 2, 2 4 278 173
  edit "", 3, 158 21 119 60, read multi return hsbar vsbar
  text "Remote View:", 4, 195 10 42 8
  button "Choose New Event", 5, 93 11 49 10
  radio "Channel", 6, 102 33 37 10
  radio "PM (Query)", 7, 102 43 41 10
  radio "Channel/PM", 8, 102 53 42 10
  edit "", 9, 10 86 106 10, autohs
  text "", 10, 10 61 105 24
  text "", 11, 7 128 230 46
  button "Set Word", 12, 10 97 29 10
  button "Send To Clipboard", 13, 192 84 49 10
  button "?", 14, 146 11 7 10
  button "Exit", 15, 245 165 32 10, ok
  box "Info/Help", 16, 3 120 238 56
  text "Activate in:", 17, 98 25 47 8
  button "Set Nick", 18, 48 97 29 10
  button "Command", 19, 86 97 29 10
  button "Skip Step", 20, 48 108 29 10
  button "Skip Step", 21, 10 108 29 10
  button "Help", 22, 86 108 29 10
}
dialog noobie.help {
  title "Commands List Help Center - Made By: Kurdish_Assass1n"
  size -1 -1 239 144
  option dbu
  button "OK/DONE", 2, 198 131 37 11, ok cancel
  list 1, 6 13 226 114, size hsbar
  box "Commands List Help Center", 3, 3 5 232 124
  button "Get Commands", 4, 3 131 38 11, hide
  text "Double-click an item for more information/help", 5, 41 131 157 11, center
}

On *:dialog:remote.creator:*:*: {
  if ($devent == sclick) {
    if ($did == 22) {
      ;Help.center
      if (!$dialog(noobie.help)) {
        noobie.help
      }
      else { echo -e  9*ERROR: Help Center is already opened }
    }
    if ($did == 19) {
      ;Command
      %xbrackets = $did($xrem,3).lines
      did -b $xrem 9,19
      did -a $xrem 3 $crlf $did($xrem,9) $str($crlf $chr(125),%xbrackets)
      did -e $xrem 13
      did -a $xrem 11 You will have to load this into Remotes (ALT + R) for this script to activate. $crlf $crlf For best results, paste this into a new script file, here's how: $crlf Goto Script Editor -> Hit 'Remote' tab -> File -> New -> Paste Script -> Hit 'OK'
      did -r $xrem 9
    }
    if ($did == 20) { 
      ;Skip Step
      did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
      did -r $xrem 9
      did -b $xrem 18,20
      did -e $xrem 22
      set %xnum 19
    }
    if ($did == 18) {
      ;Set Nick
      set %xnum 19
      did -b $xrem 18,20
      did -e $xrem 22
      did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
      did -a $xrem 3 $crlf if ( $+ $!nick == $did($xrem,9) $+ ) $chr(123)
      did -r $xrem 9
    }
    if ($did == 12) {
      if ($wrd == Input) { 
        did -a $xrem 3 $crlf if ( $+ $did($xrem,9) iswm $!1- $+ ) $chr(123)
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -b $xrem 12
        did -r $xrem 9
        set %xnum 19
      }
      elseif ($wrd == ERROR) {
        did -a $xrem 3 $crlf if ( $+ $did($xrem,9) iswm $!1- $+ ) $chr(123)
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -b $xrem 12
        did -r $xrem 9
        set %xnum 19
      }
      else {
        ;Set Word
        did -a $xrem 3 $crlf if ( $+ $did($xrem,9) iswm $!1- $+ ) $chr(123)
        did -ra $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -b $xrem 12
        did -r $xrem 9
        did -b $xrem 21
        set %xnum 18
        did -e $xrem 20
      }
    }
    if ($did == 13) {
      ;Send To Clipboard
      var %x = 0
      clipboard
      while (%x < $did($xrem,3).lines) {
        inc %x
        clipboard -a $crlf $did($xrem,3,%x)
      }
    }
    if ($did == 1) { 
      ;Combo List
      did -b $xrem 1
      did -e $xrem 5,14
      if ($wrd == Snotice) {
        did -ra $xrem 3 on *:SNOTICE:*: $chr(123)
        did -a $xrem 10 Word for Script to activate on:
        did -a $xrem 11 text matches if text contains only this word $crlf text* matches if text starts with this word $crlf *text matches if text ends with this word $crlf *text* matches if text contains this word anywhere $crlf $crlf The on CHAT event triggers when a message is sent to a dcc chat.
        did -b $xrem 6-8
        did -e $xrem 9,21
        set %xnum 12
      }
      if ($wrd == INVITE) {
        did -ra $xrem 3 on *:INVITE: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 The on INVITE event triggers when a user invites you to a channel. $str($crlf,6) *Note: Script activates for channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == Logon) {
        did -ra $xrem 3 on *:LOGON:*: $chr(123)
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on LOGON event triggers before and after mIRC sends the standard PASS, NICK, and USER messages to the server. $crlf Identifiers: $crlf $!network returns the name of the IRC network you are currently connected to. $crlf $!server returns the name of the server to which you are currently connected.
        did -b $xrem 6-8
        did -e $xrem 9
        set %xnum 19
      }
      if ($wrd == Chat) {
        did -ra $xrem 3 on *:CHAT:*: $chr(123)
        did -a $xrem 10 Word for Script to activate on:
        did -a $xrem 11 text matches if text contains only this word $crlf text* matches if text starts with this word $crlf *text matches if text ends with this word $crlf *text* matches if text contains this word anywhere $crlf $crlf The on CHAT event triggers when a message is sent to a dcc chat.
        did -b $xrem 6-8
        did -e $xrem 9,21
        set %xnum 12
      }
      if ($wrd == Error) {
        did -ra $xrem 3 on *:ERROR:*: $chr(123)
        did -a $xrem 10 Word for Script to activate on:
        did -a $xrem 11 text matches if text contains only this word $crlf text* matches if text starts with this word $crlf *text matches if text ends with this word $crlf *text* matches if text contains this word anywhere $crlf $crlf The on ERROR event triggers when an IRC Server sends an ERROR message, this usually occurs on a disconnection.
        did -b $xrem 6-8
        did -e $xrem 9,21
        set %xnum 12
      }
      if ($wrd == Usermode) {
        did -ra $xrem 3 on *:USERMODE: $chr(123)
        did -b $xrem 6-8,18,20
        did -e $xrem 9
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on USERMODE event triggers when you change your usermode. $crlf Identifiers: $crlf $!1- parameter refer to the new usermode. $crlf $!nick refers to the nick.
        set %xnum 19
      }
      if ($wrd == Unotify) {
        did -ra $xrem 3 on *:UNOTIFY: $chr(123)
        did -b $xrem 6-8,18
        did -e $xrem 9,20
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on UNOTIFY events trigger when a user in your notify list leaves IRC.
        set %xnum 18
      }
      if ($wrd == Notify) {
        did -ra $xrem 3 on *:NOTIFY: $chr(123)
        did -b $xrem 6-8,18
        did -e $xrem 9,20
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on NOTIFY events trigger when a user in your notify list joins IRC.
        set %xnum 18
      }
      if ($wrd == Start) {
        did -ra $xrem 3 on *:START: $chr(123)
        did -b $xrem 6-8,18,20
        did -e $xrem 9
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on START event uses the same format, and triggers the first time a script is loaded and every time after that when mIRC is run.
        set %xnum 19
      }
      if ($wrd == Unload) {
        did -ra $xrem 3 on *:UNLOAD: $chr(123)
        did -b $xrem 6-8,18,20
        did -e $xrem 9
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on UNLOAD event triggers the first time a script file is unloaded.
        set %xnum 19
      }
      if ($wrd == Load) {
        did -ra $xrem 3 on *:LOAD: $chr(123)
        did -b $xrem 6-8,18,20
        did -e $xrem 9
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on LOAD event triggers the first time a script file is loaded.
        set %xnum 19
      }
      if ($wrd == Exit) {
        did -ra $xrem 3 on *:EXIT: $chr(123)
        did -b $xrem 6-8,18,20
        did -e $xrem 9
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on EXIT event triggers when mIRC itself is closed. $crlf The main purpose of this command is to allow scripts to exit cleanly, unset variables, save settings, etc. when mIRC exits.
        set %xnum 19
      }
      if ($wrd == DNS) {
        did -ra $xrem 3 on *:DNS: $chr(123)
        did -b $xrem 6-8,18,20
        did -e $xrem 9
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on DNS event triggers when a /dns query either succeeds or fails. $crlf Identifiers: $crlf $!dns(0).nick/addr/ip refers to properties if an address couldn't be resolved. $crlf $!raddress
        set %xnum 19
      }
      if ($wrd == APPACTIVE) {
        did -ra $xrem 3 on *:APPACTIVE: $chr(123)
        did -b $xrem 6-8,18,20
        did -e $xrem 9
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 The on APPACTIVE events trigger when mIRC's active status changes respectively. $crlf Identifiers: $crlf $!active returns the full name of the currently active window. $crlf $!lactive returns full window name of the last active window. $crlf $!activecid refers to a window identifier that has it's own connection id. $crlf $!lactivecid refers to a window identifier that has it's own connection id.
        set %xnum 19
      }
      if ($wrd == CONNECT) {
        did -ra $xrem 3 on *:CONNECT: $chr(123)
        did -b $xrem 6-8,18,20
        did -e $xrem 9
        did -ra $xrem 10 Please set a command to do if all statements are true, example: msg $!1 Hi!
        did -a $xrem 11 Many Identifiers will work with this command, please see help section for all of them. $crlf Main Identifiers: $crlf $!server returns the name of the server to which you are currently connected. $crlf $!network returns the name of the IRC network you are currently connected to. $crlf $!time returns the current time in hour:minute:second format. $crlf The on CONNECT event triggers when mIRC connects to an IRC Server right after the MOTD is displayed.
        set %xnum 19
      }
      if ($wrd == Action) {
        did -ra $xrem 3 on *:ACTION:*:
        did -a $xrem 10 $str($crlf,2) Word for Script to activate on:
        did -a $xrem 11 text matches if text contains only this word $crlf text* matches if text starts with this word $crlf *text matches if text ends with this word $crlf *text* matches if text contains this word anywhere $crlf $crlf The On Action event triggers when someone uses '/me'
        did -e $xrem 6-8
      }
      if ($wrd == Input) {
        did -ra $xrem 3 on *:INPUT:
        did -a $xrem 10 Word for Script to activate on:
        did -a $xrem 11 text matches if text contains only this word $crlf text* matches if text starts with this word $crlf *text matches if text ends with this word $crlf *text* matches if text contains this word anywhere $crlf $crlf The on INPUT event triggers when you enter text in an editbox and press enter.
        did -e $xrem 6-8
        set %xnum 12
      }
      if ($wrd == NICK) {
        did -ra $xrem 3 on *:NICK: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!newnick returns new nick. $crlf $!nick returns the person who changed their nick. $crlf $crlf The on NICK event triggers when a user changes nickname while on the same channel as you.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == Notice) {
        did -ra $xrem 3 on *:NOTICE:*:
        did -a $xrem 10 $str($crlf,2) Word for Script to activate on:
        did -a $xrem 11 text matches if text contains only this word $crlf text* matches if text starts with this word $crlf *text matches if text ends with this word $crlf *text* matches if text contains this word anywhere $crlf $crlf The On Notice event triggers when a user uses a '/notice' on you.
        did -e $xrem 6-8
      }
      if ($wrd == Op) {
        did -ra $xrem 3 on *:OP:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!opnick refers to the nickname of the person being opped/deopped. $crlf $!vnick refers to the nickname of the person being voiced/devoiced. $crlf $!hnick refers to the nickname of the person being halfopped/dehalfopped. $crlf $crlf The on OP event triggers when a user on a channel is opped. $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == Deop) {
        did -ra $xrem 3 on *:DEOP:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!opnick refers to the nickname of the person being opped/deopped. $crlf $!vnick refers to the nickname of the person being voiced/devoiced. $crlf $!hnick refers to the nickname of the person being halfopped/dehalfopped. $crlf $crlf The on DEOP event triggers when a user on a channel is deopped. $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == halfop) {
        did -ra $xrem 3 on *:HELP:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step' 
        did -a $xrem 11 Identifiers: $crlf $!opnick refers to the nickname of the person being opped/deopped. $crlf $!vnick refers to the nickname of the person being voiced/devoiced. $crlf $!hnick refers to the nickname of the person being halfopped/dehalfopped. $crlf $crlf The on HELP event triggers when a user on a channel is halfopped. $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == dehalfop) {
        did -ra $xrem 3 on *:DEHELP:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!opnick refers to the nickname of the person being opped/deopped. $crlf $!vnick refers to the nickname of the person being voiced/devoiced. $crlf $!hnick refers to the nickname of the person being halfopped/dehalfopped. $crlf $crlf The on DEHELP event triggers when a user on a channel is dehalfopped. $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == voice) {
        did -ra $xrem 3 on *:VOICE:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!opnick refers to the nickname of the person being opped/deopped. $crlf $!vnick refers to the nickname of the person being voiced/devoiced. $crlf $!hnick refers to the nickname of the person being halfopped/dehalfopped. $crlf $crlf The on VOICE event triggers when a user on a channel is voiced. $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == devoice) {
        did -ra $xrem 3 on *:DEVOICE:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!opnick refers to the nickname of the person being opped/deopped. $crlf $!vnick refers to the nickname of the person being voiced/devoiced. $crlf $!hnick refers to the nickname of the person being halfopped/dehalfopped. $crlf $crlf The on DEVOICE event triggers when a user on a channel is devoiced. $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == Text) {
        did -ra $xrem 3 on *:TEXT:*:
        did -a $xrem 10 $str($crlf,2) Word for Script to activate on:
        did -a $xrem 11 text matches if text contains only this word $crlf text* matches if text starts with this word $crlf *text matches if text ends with this word $crlf *text* matches if text contains this word anywhere $crlf $crlf The on TEXT event triggers when you receive private and/or channel messages.
        did -e $xrem 6-8
      }
      if ($wrd == Join) {
        did -ra $xrem 3 on *:JOIN:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 The on JOIN events triggers when a user joins a channel. $str($crlf,6) *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == part) {
        did -ra $xrem 3 on *:PART:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 The on PART events triggers when a user parts a channel. $str($crlf,6) *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == Quit) {
        did -ra $xrem 3 on *:QUIT: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 The on QUIT event triggers when a user quits mIRC while on the same channel as you. $crlf $!1- refers to the quit message.
        did -b $xrem 6-8
        did -e $xrem 9,21
        set %xnum 12
      }
      if ($wrd == BAN) {
        did -ra $xrem 3 on *:BAN:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!banmask refers to the banmask used to ban the user. $crlf $!bnick refers to the banned users nickname. $crlf $crlf The on BAN event triggers when a user on a channel is banned. $crlf $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == UNBAN) {
        did -ra $xrem 3 on *:UNBAN:#: $chr(123)
        did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!banmask refers to the banmask used to ban the user. $crlf $!bnick refers to the banned users nickname. $crlf $crlf The on UNBAN event triggers when a user on a channel is unbanned. $crlf $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,20
        set %xnum 18
      }
      if ($wrd == kick) {
        did -ra $xrem 3 on *:KICK:#: $chr(123)
        did -a $xrem 10 Please set a specific kick MSG for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf $!knick refers to the nickname of the user who was kicked. $crlf $!1- Refers to the kick message. $crlf $crlf The on KICK event triggers when a user is kicked from a channel. $crlf $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,21
        set %xnum 12
      }
      if ($wrd == Topic) {
        did -ra $xrem 3 on *:TOPIC:#: $chr(123)
        did -a $xrem 10 Please set a specific WORD for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
        did -a $xrem 11 Identifiers: $crlf The $!1- parameters hold the actual text of the new topic. $crlf $!nick refers to the person who set the topic. $crlf $crlf The on TOPIC event triggers when a user changes a channel topic. $crlf $crlf *NOTE: Script activates in channel only.
        did -c $xrem 6
        did -b $xrem 6-8
        did -e $xrem 9,21
        set %xnum 12
      }
    }
    if ($did == 5) { 
      did -r $xrem 3,9-11
      did -b $xrem 5-9,12-14,18-21
      did -e $xrem 1
      did -u $xrem 6-8
      set %xnum 12
    }
    if ($did == 14) { help on $wrd }
    if ($did == 21) {
      did -b $xrem 12
      did -b $xrem 21
      did -r $xrem 9
      did -f $xrem 9
      did -e $xrem 20
      did -a $xrem 10 Please set a specific nick for the script to activate on, if you would like to skip this step, simply hit 'Skip Step'
      set %xnum 18
    }
    if ($did == 6) {
      did -a $xrem 3 #: $chr(123) | did -b $xrem 6-8 | did -e $xrem 9 | set %xnum 12
      if ($wrd == Nick) { did -b $xrem 9 }
      if ($wrd == Action) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Topic) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Kick) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Text) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Notice) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Quit) { did -e $xrem 9,15,21 | $xskip  }
      if ($wrd == Input) { did -e $xrem 9,15,21 | $xskip }
    }
    if ($did == 7) { 
      did -a $xrem 3 ?: $chr(123) | did -b $xrem 6-8 | did -e $xrem 9 | set %xnum 12 
      if ($wrd == Nick) { did -b $xrem 9 }
      if ($wrd == Action) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Topic) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Kick) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Text) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Notice) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Quit) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Input) { did -e $xrem 9,15,21 | $xskip }
    }
    if ($did == 8) { 
      did -a $xrem 3 *: $chr(123) | did -b $xrem 6-8 | did -e $xrem 9 | set %xnum 12 
      if ($wrd == Nick) { did -b $xrem 9 }
      if ($wrd == Action) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Topic) { did -e $xrem 9,15,21 | $xskip  }
      if ($wrd == Kick) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Text) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Notice) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Quit) { did -e $xrem 9,15,21 | $xskip }
      if ($wrd == Input) { did -e $xrem 9,15,21 | $xskip }
    }
  }
  if ($devent == close) {
    .unset %xnum
    .unset %xbrackets
  }
  if ($devent == init) {
    did -b $xrem 5-9,12-14,18-20,22
    did -a $xrem 1 On Action Event
    did -a $xrem 1 On Appactive Event
    did -a $xrem 1 On Ban Event
    did -a $xrem 1 On Chat Event
    did -a $xrem 1 On Connect Event
    did -a $xrem 1 On Dehalfop Event
    did -a $xrem 1 On Deop Event
    did -a $xrem 1 On Devoice Event
    did -a $xrem 1 On DNS Event
    did -a $xrem 1 On Error Event
    did -a $xrem 1 On Exit Event
    did -a $xrem 1 On Halfop Event
    did -a $xrem 1 On Input Event
    did -a $xrem 1 On Invite Event
    did -a $xrem 1 On Join Event
    did -a $xrem 1 On Kick Event
    did -a $xrem 1 On Load Event
    did -a $xrem 1 On Logon Event
    did -a $xrem 1 On Nick Event
    did -a $xrem 1 On Notice Event
    did -a $xrem 1 On Notify Event
    did -a $xrem 1 On Op Event
    did -a $xrem 1 On Part Event
    did -a $xrem 1 On Quit Event
    did -a $xrem 1 On Snotice Event
    did -a $xrem 1 On Start Event
    did -a $xrem 1 On Text Event
    did -a $xrem 1 On Topic Event
    did -a $xrem 1 On Unban Event
    did -a $xrem 1 On Unotify Event
    did -a $xrem 1 On Unload Event
    did -a $xrem 1 On Usermode Event
    did -a $xrem 1 On Voice Event
    did -b $xrem 21
  }
  if ($devent == edit) {
    if (%xNum) {
      if ($did == 9) {
        if (!$did(9)) { did -b $xrem %xnum }
        if ($did(9)) { did -e $xrem %xnum }
      }
    }
  }
}

alias noobie.help { dialog -mdro noobie.help noobie.help }
alias help.titlebar {
  var %i 0
  while (%i <= 53) {
    dialog -t noobie.help $left(Commands List Help Center - Made By: Kurdish_Assass1n,%i)
    var %t 1
    while (%t <= 400) inc %t
    inc %i
  }
}
on *:dialog:noobie.help:*:*: {
  if ($devent == init) {
    .timer -m 1 1 help.titlebar
    did -v noobie.help 4
    did -az noobie.help 1 Most Commonly Used Commands
    did -az noobie.help 1 $chr(32)
    did -az noobie.help 1 /action {action text} Sends the specifed action to the active channel or query window. 
    did -az noobie.help 1 /echo  [nickname|#channel|status] {text} Displays the given text only to YOU on the given place in color N. 
    did -az noobie.help 1 /invite {nickname} {#channel} Invites another user to a channel. 
    did -az noobie.help 1 /me {action text} Sends the specifed action to the active channel or query window. Also see /describe and /ctcp action. 
    did -az noobie.help 1 /msg {nickname} {message} Send a private message to this user without opening a query window. 
    did -az noobie.help 1 /nick {new nickname} Changes your nickname to whatever you like. 
    did -az noobie.help 1 /notice {nick} {message} Send the specified notice message to the nick. 
    did -az noobie.help 1 /quit [reason] Disconnect you from IRC with the optional byebye message. 
    did -az noobie.help 1 /topic {#channel} {newtopic} Changes the topic for the specified channel. 
    did -az noobie.help 1 $chr(32)
    did -az noobie.help 1 $chr(32)
    did -az noobie.help 1 Many Other Commands To Use
    did -az noobie.help 1 $chr(32)
  }

  if ($devent == sclick) {
    if ($did == 4) {
      com-list
      did -h noobie.help 4
    }
  }
  if ($devent == dclick) {
    if ($did == 1) {
      if ($left($did(noobie.help,1,$did(noobie.help,1).sel),1) == /) { help $gettok($did(noobie.help,1,$did(noobie.help,1).sel),1,32) }
    }
  }
}

alias com-list { sockopen cmd-list mirc.com 80 }
on *:SOCKOPEN:cmd-list: {
  if ($sockerr) { echo -a ERROR: Please try at another time. | return }
  sockwrite -n $sockname GET /cmds.html
  sockwrite -n $sockname Host: mirc.com
  sockwrite -n $sockname
}

on *:SOCKREAD:cmd-list: {
  var %cmdlist
  sockread %cmdlist
  if (*Recalls the previous* iswm %cmdlist) { set %cmd.found $true }
  if (%cmd.found == $true) { 
    if ($dialog(noobie.help)) { did -az noobie.help 1 $remove(%cmdlist,<br>) }
  }
  if (*</FONT>* iswm %cmdlist) { unset %cmd.found }
}

;------------[ Aliases ]------------
alias xrem { return Remote.Creator }
alias wrd { return $gettok($did($dname,1),2,32) }
alias remote.creator { 
  if ($dialog(remote.creator)) { 
    echo -ae  9 * ERROR:  15Remote Creator is already open, please close it to go further.
    dialog -e remote.creator remote.creator
  }
  if (!$dialog(remote.creator)) {
    dialog -mdro Remote.Creator Remote.creator 
  }
}
Menu Channel,Status,Menubar {
  Noobie Remote Creator:remote.creator
}
alias xskip {
  return did -ra $xrem 10 Please set a specific word for this script to activate on. If you would like to skip this step, simply hit 'Skip Step'
}